;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "datetime" "20250203.2047"
  "Parsing, formatting and matching timestamps."
  '((emacs  "25.1")
    (extmap "1.1.1"))
  :url "https://github.com/doublep/datetime"
  :commit "2601120d4d2857cdbad1cf8d4b84d77308920835"
  :revdesc "2601120d4d28"
  :keywords '("lisp" "i18n")
  :authors '(("Paul Pogonyshev" . "pogonyshev@gmail.com"))
  :maintainers '(("Paul Pogonyshev" . "pogonyshev@gmail.com")))
